

set -ex



test -f $PREFIX/targets/x86_64-linux/lib/libcusolver_static.a
test -f $PREFIX/targets/x86_64-linux/lib/libcusolver_lapack_static.a
test -f $PREFIX/targets/x86_64-linux/lib/libcusolver_metis_static.a
test -f $PREFIX/targets/x86_64-linux/lib/libmetis_static.a
exit 0
